Tutorials
=======================
The following Notebooks give a brief introduction to ZnTrack and how it can be used.
For the best experience they can be accessed through an interactive Jupyter-Lab provided by `Binder <https://mybinder.org>`_.
The notebooks can be found in :code:`/examples/docs`.

.. image:: https://mybinder.org/badge_logo.svg
 :target: https://mybinder.org/v2/gh/zincware/ZnTrack/HEAD


.. toctree::
   :maxdepth: 1

   _overview/01_Intro.ipynb
   _overview/02_PassingClasses.ipynb
   _overview/03_dependencies.ipynb
   _overview/04_metrics_and_plots.ipynb
   _overview/05_metadata.ipynb
   _overview/06_named_nodes.ipynb
   _overview/OptionalDVC.ipynb
   jupyter.rst
